import _plotly_utils.basevalidators


class ShowlabelsValidator(_plotly_utils.basevalidators.BooleanValidator):

    def __init__(
        self,
        plotly_name='showlabels',
        parent_name='contourcarpet.contours',
        **kwargs
    ):
        super(ShowlabelsValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='plot',
            role='style',
            **kwargs
        )



import _plotly_utils.basevalidators


class XboundssrcValidator(_plotly_utils.basevalidators.SrcValidator):

    def __init__(
        self, plotly_name='xboundssrc', parent_name='pointcloud', **kwargs
    ):
        super(XboundssrcValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='none',
            role='info',
            **kwargs
        )



import _plotly_utils.basevalidators


class RowValidator(_plotly_utils.basevalidators.IntegerValidator):

    def __init__(self, plotly_name='row', parent_name='pie.domain', **kwargs):
        super(RowValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='calc',
            min=0,
            role='info',
            **kwargs
        )
